@@ -13,10 +13,11 @@ from rich.logging import RichHandler
 
 FORMAT = "%(message)s"
 logging.basicConfig(
-    level="NOTSET", format=FORMAT, datefmt="[%X]",
+    level=logging.INFO, format=FORMAT, datefmt="[%X]",
     handlers=[RichHandler(console=Console(stderr=True))]
 )
 log = logging.getLogger("rich")
+log.setLevel(logging.INFO)
 
 sys.path.append(
     os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe()))))
@@ -165,6 +166,63 @@ def show_cache():
                 lf.archive_name))
 
 
+@click.command()
+@transaction.atomic()
+def show_archives():
+    """Clear the import cache"""
+    from constants import archives
+
+    for key, value in archives.items():
+        logging.info(value.name())
+
+
+@click.command()
+@click.argument('archive_name')
+@click.option('--count',
+              default=25,
+              help='Give random samples for an archive')
+@transaction.atomic()
+def random_samples(archive_name, count):
+    """Return random samples that occur in and out of an archive"""
+    from constants import archives
+    import utils
+
+    archive = None
+
+    for key, archive_object in archives.items():
+        if archive_object.name() == archive_name:
+            archive = archive_object
+
+    if not archive:
+        log.error(f'Archive {archive_name} not found')
+        return
+
+    random_entries = utils.random_db_entries(archive, count)
+    not_in_archive = []
+
+    # now find entries that are not in the archive:
+    while len(not_in_archive) < count - 1:
+        for key, other_archive in archives.items():
+            if other_archive != archive:
+                other_entries = utils.random_db_entries(other_archive, count)
+
+                for entry in other_entries:
+                    if not utils.in_archive(entry, archive):
+                        not_in_archive.append(entry)
+
+                        if len(not_in_archive) == count - 1:
+                            break
+
+            if len(not_in_archive) == count - 1:
+                break
+
+    for entry in random_entries:
+        logging.info('{} contains: {}'.format(archive_name, entry))
+
+    for entry in not_in_archive:
+        logging.info('{} does not contain: {}'.format(archive_name, entry))
+
+
 @click.command()
 def import_all():
     """Download and import all data (excluding HathiTrust)"""
@@ -222,6 +280,8 @@ if __name__ == '__main__':
     cli.add_command(import_ocul)
     cli.add_command(import_pkp)
     cli.add_command(import_portico)
+    cli.add_command(random_samples)
+    cli.add_command(show_archives)
     cli.add_command(show_cache)
     cli.add_command(show_preservation)
     cli.add_command(stamp_cache_today)
