@@ -1,3 +1,6 @@
+from typing import DefaultDict, Any
+
+
 def get_members(s3client, samples_bucket, samples_path) -> list[str]:
     """
     Retrieves the list of members from the S3 bucket
@@ -92,19 +95,25 @@ def preservation_status(result) -> (dict, str):
     return show_preservation(container_title, issn, volume, no, doi)
 
 
-def process_member_sample(samples) -> dict:
+def process_member_sample(samples, sample_path) -> dict:
     """
     Processes samples for a single member
     :param samples: the samples to process
+    :param sample_path: the path of the sample
     :return: a dictionary of preservation statistics
     """
     from constants import archives
+    from datetime import datetime
+    import json
 
     from collections import defaultdict
-    overall_status = defaultdict(int)
+    overall_status: DefaultDict[Any, Any] = defaultdict(int)
 
-    import json
-    import logging
+    # date stamp this output
+    overall_status['about'] = {
+        'date-generated': str(datetime.now()),
+        'sample-file': sample_path
+    }
 
     for sample_item in samples:
         result = json.loads(sample_item)['data-point']
@@ -163,3 +172,32 @@ def push_json_to_s3(s3, json_obj, member_id, annotation_bucket, annotation_path,
 
     obj = s3.Object(annotation_bucket, key)
     obj.put(Body=json.dumps(json_obj))
+
+
+def process_sample(annotation_bucket, annotation_filename, annotation_path,
+                   samples_bucket, samples_path, member_id, s3, s3client):
+    """
+    Process a single member sample
+    :param annotation_bucket: the annotation bucket
+    :param annotation_filename: the annotation filename
+    :param annotation_path: the annotation path
+    :param samples_bucket: the samples bucket
+    :param samples_path: the samples path
+    :param member_id: the member id
+    :param s3: s3 object
+    :param s3client: s3client object
+    :return:
+    """
+    import logging
+
+    logging.info(f'Processing member {member_id}')
+
+    samples = get_samples(s3client, member_id, samples_bucket=samples_bucket,
+                          samples_path=samples_path)
+
+    overall_status = process_member_sample(samples, samples_path)
+
+    push_json_to_s3(s3, overall_status, member_id,
+                    annotation_bucket=annotation_bucket,
+                    annotation_path=annotation_path,
+                    annotation_filename=annotation_filename)
