@@ -90,6 +90,16 @@ class LockssPreservation(models.Model):
     publisher = models.ForeignKey(Publisher, on_delete=models.CASCADE,
                                   default=None)
 
+    def __str__(self):
+        return '{} (issn: {}) (eissn: {}) (v{}({})) ' \
+               '(in progress: {} ({})) '.format(self.title, self.issn,
+                                                self.eissn,
+                                                self.preserved_volumes,
+                                                self.preserved_years,
+                                                self.in_progress_volumes,
+                                                self.in_progress_years
+                                                )
+
     @staticmethod
     def name() -> str:
         return "LOCKSS"
@@ -167,6 +177,16 @@ class CarinianaPreservation(models.Model):
     publisher = models.ForeignKey(Publisher, on_delete=models.CASCADE,
                                   default=None)
 
+    def __str__(self):
+        return '{} (issn: {}) (eissn: {}) (v{}({})) ' \
+               '(in progress: {} ({})) '.format(self.title, self.issn,
+                                                self.eissn,
+                                                self.preserved_volumes,
+                                                self.preserved_years,
+                                                self.in_progress_volumes,
+                                                self.in_progress_years
+                                                )
+
     @staticmethod
     def name() -> str:
         return "Cariniana"
@@ -244,6 +264,16 @@ class ClockssPreservation(models.Model):
     publisher = models.ForeignKey(Publisher, on_delete=models.CASCADE,
                                   default=None)
 
+    def __str__(self):
+        return '{} (issn: {}) (eissn: {}) (v{}({})) ' \
+               '(in progress: {} ({})) '.format(self.title, self.issn,
+                                                self.eissn,
+                                                self.preserved_volumes,
+                                                self.preserved_years,
+                                                self.in_progress_volumes,
+                                                self.in_progress_years
+                                                )
+
     @staticmethod
     def name() -> str:
         return "CLOCKSS"
@@ -317,6 +347,12 @@ class PKPPreservation(models.Model):
     publisher = models.ForeignKey(Publisher, on_delete=models.CASCADE,
                                   default=None)
 
+    def __str__(self):
+        return '{} (issn: {}) (v{}({})) '.format(self.title, self.issn,
+                                                 self.preserved_volumes,
+                                                 self.preserved_no,
+                                                 )
+
     @staticmethod
     def name() -> str:
         return "PKP PLN"
@@ -389,6 +425,10 @@ class HathiPreservation(models.Model):
     issn = models.CharField(max_length=20)
     preserved_volumes = models.TextField()
 
+    def __str__(self):
+        return '{} (issn: {}) (v{}) '.format(self.title, self.issn,
+                                             self.preserved_volumes)
+
     @staticmethod
     def name() -> str:
         return "HathiTrust"
@@ -532,6 +572,11 @@ class PorticoPreservation(models.Model):
     publisher = models.ForeignKey(Publisher, on_delete=models.CASCADE,
                                   default=None)
 
+    def __str__(self):
+        return '{} (issn: {}) (eissn: {}) (v{}) '.format(self.title,
+                                                         self.issn, self.eissn,
+                                                         self.preserved_volumes)
+
     @staticmethod
     def name():
         return 'Portico'
@@ -658,6 +703,11 @@ class OculScholarsPortalPreservation(models.Model):
     publisher = models.ForeignKey(Publisher, on_delete=models.CASCADE,
                                   default=None)
 
+    def __str__(self):
+        return '{} (issn: {}) (v{}({})) '.format(self.title, self.issn,
+                                                 self.preserved_volumes,
+                                                 self.preserved_no)
+
     @staticmethod
     def name():
         return 'OCUL Scholars Portal'
@@ -665,16 +715,16 @@ class OculScholarsPortalPreservation(models.Model):
     @staticmethod
     def preservation(container_title, issn, volume, no=None):
         """
-        Determine whether a DOI is preserved in Portico
+        Determine whether a DOI is preserved in OCUL Scholars Portal
         :param container_title: the container title
         :param issn: the ISSN
         :param volume: the volume
         :param no: the issue number
-        :return: A PorticoPreservation item (or None) and a bool indicating
-        whether the item is fully preserved
+        :return: An OculScholarsPortalPreservation item (or None) and a bool
+        indicating whether the item is fully preserved
         """
-        preserved_item = utils.get_preserved_item_record(PorticoPreservation,
-                                                         container_title, issn)
+        preserved_item = utils.get_preserved_item_record(
+            OculScholarsPortalPreservation, container_title, issn)
 
         if not preserved_item or len(preserved_item) == 0:
             return None, False
