@@ -9,7 +9,9 @@ from random import randint
 import django
 import requests
 from crossref.restful import Etiquette, Works
+from django.db import transaction
 from django.db.models import QuerySet, Count
+
 from lxml import etree as ET
 
 
@@ -388,6 +390,7 @@ def normalize_issn(issn) -> str:
     return f'{issn[0:4]}-{issn[4:8]}' if issn and '-' not in issn else issn
 
 
+@transaction.atomic
 def random_db_entries(model, count) -> list:
     """
     Returns random entries from a database model
